####################
Python API reference
####################

.. contents:: Modules
   :local:
   :depth: 1
   :backlinks: none

.. automodapi:: documenteer.sphinxconfig.stackconf
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxconfig.technoteconf
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxconfig.utils
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxext
   :no-inheritance-diagram:

.. FIXME I couldn't get intersphinx to resolve inherited members, and no-inherited-members doesn't work, hence I'm skipping this API.

.. automodapi:: documenteer.sphinxext.bibtex
   :no-inherited-members:
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxext.jira
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxext.lsstdocushare
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxext.mockcoderefs
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxext.packagetoctree
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.build
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.doxygen
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.packagecli
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.pkgdiscovery
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.rootdiscovery
   :no-inheritance-diagram:

.. automodapi:: documenteer.stackdocs.stackcli
   :no-inheritance-diagram:

.. automodapi:: documenteer.requestsutils
   :no-inheritance-diagram:

.. automodapi:: documenteer.sphinxrunner
   :no-inheritance-diagram:
